@@ -95,6 +95,16 @@ class EdgeIterator(object):
         )
         self._queue = []
         self._finished_iteration = False
+        self._total_count = None
+
+        if self._source_object.get_api():
+            self.load_next_page()
+
+    def __repr__(self):
+        return str(self._queue)
+
+    def __len__(self):
+        return len(self._queue)
 
     def __iter__(self):
         return self
@@ -109,6 +119,9 @@ class EdgeIterator(object):
 
     next = __next__
 
+    def total(self):
+        return self._total_count
+
     def load_next_page(self):
         """Queries server for more nodes and loads them into the internal queue.
 
@@ -118,6 +131,8 @@ class EdgeIterator(object):
         if self._finished_iteration:
             return False
 
+        self._params['summary'] = True
+
         response = self._source_object.get_api_assured().call(
             FacebookAdsApi.HTTP_METHOD_GET,
             self._path,
@@ -130,14 +145,25 @@ class EdgeIterator(object):
             # Indicate if this was the last page
             self._finished_iteration = True
 
-        num_added = 0
-        for json_obj in response['data']:
-            obj = self._target_objects_class()
-            obj._set_data(json_obj)
-            self._queue.append(obj)
-            num_added += 1
+        if 'summary' in response and 'total_count' in response['summary']:
+            self._total_count = response['summary']['total_count']
 
-        return num_added > 0
+        self._queue = self.build_objects_from_response(response)
+        return len(self._queue) > 0
+
+    def build_objects_from_response(self, response):
+        if 'data' in response:
+            ret = []
+            for json_obj in response['data']:
+                obj = self._target_objects_class()
+                obj._set_data(json_obj)
+                ret.append(obj)
+        else:
+            obj = self._target_objects_class()
+            obj._set_data(response)
+            ret = [obj]
+
+        return ret
 
 
 class AbstractObject(collections.MutableMapping):
@@ -170,9 +196,6 @@ class AbstractObject(collections.MutableMapping):
     def __contains__(self, key):
         return key in self._data
 
-    def __str__(self):
-        return str(self._data)
-
     def __unicode__(self):
         return unicode(self._data)
 
